
.onAttach <-
  function(libname, pkgname) {
    packageStartupMessage("\nThis package may be cited as:")
    packageStartupMessage('Dworschak, Christoph. 2021. "Disastr.api: Wrapper for the UN OCHA')
    packageStartupMessage('ReliefWeb Disaster Events API." R package. CRAN version 1.0.3. \n')
    packageStartupMessage("For the development version of this package, visit <https://github.com/chris-dworschak/disastr.api/> \n")
  }


